@@ -60,31 +60,10 @@ exports.Request = Request;
  */
 
 request.getXHR = () => {
-  if (
-    root.XMLHttpRequest &&
-    (!root.location ||
-      root.location.protocol !== 'file:' ||
-      !root.ActiveXObject)
-  ) {
-    return new XMLHttpRequest();
+  if (root.XMLHttpRequest) {
+    return new root.XMLHttpRequest();
   }
 
-  try {
-    return new ActiveXObject('Microsoft.XMLHTTP');
-  } catch {}
-
-  try {
-    return new ActiveXObject('Msxml2.XMLHTTP.6.0');
-  } catch {}
-
-  try {
-    return new ActiveXObject('Msxml2.XMLHTTP.3.0');
-  } catch {}
-
-  try {
-    return new ActiveXObject('Msxml2.XMLHTTP');
-  } catch {}
-
   throw new Error('Browser-only version of superagent could not find XHR');
 };
 
@@ -436,10 +415,10 @@ function Request(method, url) {
 
     try {
       res = new Response(self);
-    } catch (error_) {
+    } catch (err) {
       error = new Error('Parser is unable to parse the response');
       error.parse = true;
-      error.original = error_;
+      error.original = err;
       // issue #675: return the raw response if the response parsing fails
       if (self.xhr) {
         // ie9 doesn't have 'response' property
@@ -475,7 +454,7 @@ function Request(method, url) {
     if (new_error) {
       new_error.original = error;
       new_error.response = res;
-      new_error.status = res.status;
+      new_error.status = new_error.status || res.status;
       self.callback(new_error, res);
     } else {
       self.callback(null, res);
@@ -568,13 +547,15 @@ Request.prototype.auth = function (user, pass, options) {
     };
   }
 
-  const encoder = (string) => {
-    if (typeof btoa === 'function') {
-      return btoa(string);
-    }
+  const encoder = options.encoder
+    ? options.encoder
+    : (string) => {
+        if (typeof btoa === 'function') {
+          return btoa(string);
+        }
 
-    throw new Error('Cannot use basic auth, btoa is not a function');
-  };
+        throw new Error('Cannot use basic auth, btoa is not a function');
+      };
 
   return this._auth(user, pass, options, encoder);
 };
@@ -788,7 +769,7 @@ Request.prototype._end = function () {
     let status;
     try {
       status = xhr.status;
-    } catch {
+    } catch (err) {
       status = 0;
     }
 
@@ -823,7 +804,7 @@ Request.prototype._end = function () {
           handleProgress.bind(null, 'upload')
         );
       }
-    } catch {
+    } catch (err) {
       // Accessing xhr.upload fails in IE from a web worker, so just pretend it doesn't exist.
       // Reported here:
       // https://connect.microsoft.com/IE/feedback/details/837245/xmlhttprequest-upload-throws-invalid-argument-when-used-from-web-worker-context
