@@ -2,8 +2,8 @@
 const assert = require('assert');
 const utils =
   process.env.OLD_NODE_TEST === '1'
-    // eslint-disable-next-line node/no-missing-require
-    ? require('../../../utils')
+    ? // eslint-disable-next-line node/no-missing-require
+      require('../../../utils')
     : require('../../lib/utils');
 
 describe('utils.type(str)', () => {
